==> haskell-swagger2-2.8.10-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 swagger2
version:              2.8.10
visibility:           public
id:                   swagger2-2.8.10-CBzRjwrZOC7B1A7TKBtZJ0
key:                  swagger2-2.8.10-CBzRjwrZOC7B1A7TKBtZJ0
license:              BSD-3-Clause
copyright:            (c) 2015-2016, GetShopTV
maintainer:           nickolay@getshoptv.com
author:               Nickolay Kudasov
homepage:             https://github.com/GetShopTV/swagger2
synopsis:             Swagger 2.0 data model
description:
    This library is intended to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.

    The original Swagger 2.0 specification is available at http://swagger.io/specification/.

category:             Web, Swagger
abi:                  f8915ba71a7a40055609fbe9137ec15b
exposed:              True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.Optics
    Data.Swagger.ParamSchema Data.Swagger.Schema
    Data.Swagger.Schema.Generator Data.Swagger.Schema.Validation
    Data.Swagger.SchemaOptions

import-dirs:          /usr/lib/ghc-9.4.8/site-local/swagger2-2.8.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/swagger2-2.8.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/swagger2-2.8.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-swagger2
hs-libraries:         HSswagger2-2.8.10-CBzRjwrZOC7B1A7TKBtZJ0
depends:
    QuickCheck-2.15.0.1-I0djFeIgNIwKhHwbhHCf4p
    aeson-2.1.2.1-CM1TyKExMgH6p2KQqrdDHD
    aeson-pretty-0.8.10-3WCsO9UEOFd53JyI5jmmw7 base-4.17.2.1
    base-compat-batteries-0.13.1-Ah5C1vZQAFcDPuDHW0iUr0
    bytestring-0.11.5.3 containers-0.6.7
    cookie-0.4.6-4shfaVKBFn0Hnep1ZY6FZw
    generics-sop-0.5.1.3-1cdm4H81rvrYJuJwoMQFY
    hashable-1.4.5.0-DrXzgEMDRcV8gNOMGO5wPZ
    http-media-0.8.1.1-EAKN9zouIjp6VwHAOK11hP
    insert-ordered-containers-0.2.5.3-DOuUchnAwQD9Un7w7dBNpo
    lens-5.3.1-2VSC1EMe0UsGg1l2wcItEv mtl-2.2.2
    network-3.1.4.0-BeHm9PhAGW35QMcXomVSuT
    optics-core-0.4.1.1-DBhUaRSx1KJ90bAHs48Cy6
    optics-th-0.4.1-EmYYjn5sC6uKyVRdsWwkCm
    scientific-0.3.8.0-BCRNugtxiDS8UMOiZ0ZEsF template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    unordered-containers-0.2.20-FLM1pZb3BI5FpyNo5sVXNv
    uuid-types-1.0.6-4FBWy54GmK8HdU0HTDUBUB
    vector-0.13.2.0-LmFi28PTaN7DJJszRwFTiC

haddock-interfaces:   /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html:         /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-swagger2-2.8.10-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 swagger2
version:              2.8.10
visibility:           public
id:                   swagger2-2.8.10-BxwgNKVS7e3CnCdyI3YQIQ
key:                  swagger2-2.8.10-BxwgNKVS7e3CnCdyI3YQIQ
license:              BSD-3-Clause
copyright:            (c) 2015-2016, GetShopTV
maintainer:           nickolay@getshoptv.com
author:               Nickolay Kudasov
homepage:             https://github.com/GetShopTV/swagger2
synopsis:             Swagger 2.0 data model
description:
    This library is intended to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.

    The original Swagger 2.0 specification is available at http://swagger.io/specification/.

category:             Web, Swagger
abi:                  487d15a3328d300c2aad5c784cb3cc63
exposed:              True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.Optics
    Data.Swagger.ParamSchema Data.Swagger.Schema
    Data.Swagger.Schema.Generator Data.Swagger.Schema.Validation
    Data.Swagger.SchemaOptions

import-dirs:          /usr/lib/ghc-9.4.8/site-local/swagger2-2.8.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/swagger2-2.8.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/swagger2-2.8.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-swagger2
hs-libraries:         HSswagger2-2.8.10-BxwgNKVS7e3CnCdyI3YQIQ
depends:
    QuickCheck-2.15.0.1-KEw9aoMxM6q6i8cfYYug2V
    aeson-2.1.2.1-F8ZePgr6g4xL6kF4wsQx0x
    aeson-pretty-0.8.10-7LLoAxhJYrxHVdlJthoYBc base-4.17.2.1
    base-compat-batteries-0.13.1-290WtzUk0c8G8aQv0NA3I0
    bytestring-0.11.5.3 containers-0.6.7
    cookie-0.4.6-4shfaVKBFn0Hnep1ZY6FZw
    generics-sop-0.5.1.3-1cdm4H81rvrYJuJwoMQFY
    hashable-1.4.5.0-FUZ3820cmTgAr6H2g2EQN7
    http-media-0.8.1.1-Jnf81DzN7R06o05XXV2prV
    insert-ordered-containers-0.2.5.3-aV927UxxNKGkIQ6PVKesc
    lens-5.3.1-FP95Rv35No71PYJue58Hxp mtl-2.2.2
    network-3.1.4.0-7GxbLibXQB6BN49yptQL65
    optics-core-0.4.1.1-6kH0gXA1PYjI55XMoTw87h
    optics-th-0.4.1-BK5flOjVIJaEwaOioNfsuf
    scientific-0.3.8.0-IrrbGrT9lim10QS5UtlqtE template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    unordered-containers-0.2.20-I3GOf8berWn8tol6ImoSEe
    uuid-types-1.0.6-1cjjiQgFLzL6lLsdFHJBaX
    vector-0.13.2.0-7bZcynEBhMGLMgNICkU4Wg

haddock-interfaces:   /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html:         /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
